# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import winrt.system
from winrt._winrt_windows_devices_background import (
    DeviceServicingDetails,
    DeviceUseDetails,
)

__all__ = [
    "DeviceServicingDetails",
    "DeviceUseDetails",
]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class DeviceServicingDetails(winrt.system.Object):
    # System.String Windows.Devices.Background.DeviceServicingDetails::get_Arguments()
    @_property
    def arguments(self) -> str: ...
    # System.String Windows.Devices.Background.DeviceServicingDetails::get_DeviceId()
    @_property
    def device_id(self) -> str: ...
    # Windows.Foundation.TimeSpan Windows.Devices.Background.DeviceServicingDetails::get_ExpectedDuration()
    @_property
    def expected_duration(self) -> datetime.timedelta: ...

@typing.final
class DeviceUseDetails(winrt.system.Object):
    # System.String Windows.Devices.Background.DeviceUseDetails::get_Arguments()
    @_property
    def arguments(self) -> str: ...
    # System.String Windows.Devices.Background.DeviceUseDetails::get_DeviceId()
    @_property
    def device_id(self) -> str: ...

